@@ -12,9 +12,8 @@ from .fields import EncryptedField
 class ProviderManager(models.Manager):
     "Additional manager methods for Providers."
 
-    def enabled(self):
-        "Filter down providers which have key/secret pairs."
-        return super(ProviderManager, self).filter(key__isnull=False, secret__isnull=False)
+    def get_by_natural_key(self, name):
+        return self.get(name=name)
 
 
 @python_2_unicode_compatible
@@ -22,12 +21,12 @@ class Provider(models.Model):
     "Configuration for OAuth provider."
 
     name = models.CharField(max_length=50, unique=True)
-    request_token_url = models.URLField(blank=True)
-    authorization_url = models.URLField()
-    access_token_url = models.URLField()
-    profile_url = models.URLField()
-    key = EncryptedField(blank=True, null=True, default=None)
-    secret = EncryptedField(blank=True, null=True, default=None)
+    request_token_url = models.CharField(blank=True, max_length=255)
+    authorization_url = models.CharField(max_length=255)
+    access_token_url = models.CharField(max_length=255)
+    profile_url = models.CharField(max_length=255)
+    consumer_key = EncryptedField(blank=True, null=True, default=None)
+    consumer_secret = EncryptedField(blank=True, null=True, default=None)
 
     objects = ProviderManager()
 
@@ -35,15 +34,26 @@ class Provider(models.Model):
         return self.name
 
     def save(self, *args, **kwargs):
-        self.key = self.key or None
-        self.secret = self.secret or None
+        self.consumer_key = self.consumer_key or None
+        self.consumer_secret = self.consumer_secret or None
         super(Provider, self).save(*args, **kwargs)
 
+    def natural_key(self):
+        return (self.name, )
+
     def enabled(self):
-        return self.key is not None and self.secret is not None
+        return self.consumer_key is not None and self.consumer_secret is not None
     enabled.boolean = True
 
 
+class AccountAccessManager(models.Manager):
+    "Additional manager for AccountAccess models."
+
+    def get_by_natural_key(self, identifier, provider):
+        provider = Provider.objects.get_by_natural_key(provider)
+        return self.get(identifier=identifier, provider=provider)
+
+
 @python_2_unicode_compatible
 class AccountAccess(models.Model):
     "Authorized remote OAuth provider."
@@ -55,6 +65,8 @@ class AccountAccess(models.Model):
     modified = models.DateTimeField(auto_now=True, default=datetime.now)
     access_token = EncryptedField(blank=True, null=True, default=None)
 
+    objects = AccountAccessManager()
+
     class Meta(object):
         unique_together = ('identifier', 'provider')
 
@@ -65,6 +77,10 @@ class AccountAccess(models.Model):
         self.access_token = self.access_token or None
         super(AccountAccess, self).save(*args, **kwargs)
 
+    def natural_key(self):
+        return (self.identifier, ) + self.provider.natural_key()
+    natural_key.dependencies = ['allaccess.provider']
+
     @property
     def api_client(self):
         return get_client(self.provider, self.access_token or '')
